==> jc-1.4.0.tar.gz: polyglot/ext/param/types/Subst__5fc__24FieldXform.h <==
// public class polyglot.ext.param.types.Subst_c$FieldXform

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ee70af5f29e4fd90 polyglot_ext_param_types_Subst__5fc__24FieldXform

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_param_types_Subst__5fc__24FieldXform_H_
#define _JC_polyglot_ext_param_types_Subst__5fc__24FieldXform_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_polyglot_ext_param_types_Subst__5fc$object;

// Typedefs
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_refs	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_refs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_nonrefs	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_nonrefs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$refs	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$refs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$nonrefs	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$nonrefs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$object	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$object;

typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vmethods	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vmethods;
typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtable	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtable;
typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtype	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtype;

// Constructors
extern void _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$method$_init$6b84d2d2ede79d86(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$object *, struct _jc_polyglot_ext_param_types_Subst__5fc$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$method$transform$ebefcdad8030daa7(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$method_info$transform$ebefcdad8030daa7;

// Virtual methods structure
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vmethods {
	struct _jc_java_lang_Object$object	*(*transform$ebefcdad8030daa7)(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vmethods	polyglot_ext_param_types_Subst__5fc__24FieldXform;
};

// Vtype
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtype {
	_jc_type			type;
	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_refs {
	struct _jc_polyglot_ext_param_types_Subst__5fc$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$refs {
    _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_refs	polyglot_ext_param_types_Subst__5fc__24FieldXform;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_nonrefs	polyglot_ext_param_types_Subst__5fc__24FieldXform;
};

// Object instance structure
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$object {
	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtype	*vtype;
	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtype _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_param_types_Subst__5fc__24FieldXform, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$class_object;

#endif	/* _JC_polyglot_ext_param_types_Subst__5fc__24FieldXform_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/param/types/Subst__5fc__24FieldXform.h <==
// public class polyglot.ext.param.types.Subst_c$FieldXform

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ee70af5f29e4fd90 polyglot_ext_param_types_Subst__5fc__24FieldXform

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_ext_param_types_Subst__5fc__24FieldXform_H_
#define _JC_polyglot_ext_param_types_Subst__5fc__24FieldXform_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_polyglot_ext_param_types_Subst__5fc$object;

// Typedefs
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_refs	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_refs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_nonrefs	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_nonrefs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$refs	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$refs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$nonrefs	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$nonrefs;
typedef struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$object	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$object;

typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vmethods	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vmethods;
typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtable	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtable;
typedef const struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtype	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtype;

// Constructors
extern void _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$method$_init$6b84d2d2ede79d86(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$object *, struct _jc_polyglot_ext_param_types_Subst__5fc$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$method$transform$ebefcdad8030daa7(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$method_info$transform$ebefcdad8030daa7;

// Virtual methods structure
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vmethods {
	struct _jc_java_lang_Object$object	*(*transform$ebefcdad8030daa7)(_jc_env *, struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vmethods	polyglot_ext_param_types_Subst__5fc__24FieldXform;
};

// Vtype
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtype {
	_jc_type			type;
	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_refs {
	struct _jc_polyglot_ext_param_types_Subst__5fc$object	*this__240;
};

// Reference instance fields (object)
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$refs {
    _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_refs	polyglot_ext_param_types_Subst__5fc__24FieldXform;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$sub_nonrefs	polyglot_ext_param_types_Subst__5fc__24FieldXform;
};

// Object instance structure
struct _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$object {
	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtype	*vtype;
	_jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$vtype _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_param_types_Subst__5fc__24FieldXform, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_param_types_Subst__5fc__24FieldXform$class_object;

#endif	/* _JC_polyglot_ext_param_types_Subst__5fc__24FieldXform_H_ */
